package com.manage.service;

import com.manage.entity.Power_Role;
import com.manage.vo.Power_RoleVo;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @Author:ly
 * @Date:Creatid in 1:18 2019/4/25
 * @Description:
 */
public interface Power_RoleService {
    int deleteByPrimaryKey(Integer roleId);

    int insert(Power_Role record);

    int insertSelective(Power_Role record);

    Power_Role selectByPrimaryKey(Integer roleId);

    int updateByPrimaryKeySelective(Power_Role record,HttpServletRequest request);

    int updateByPrimaryKey(Power_Role record);

    /**
     * @Date 2019-4-16
     * @Author ly
     *  @Description 根据条件查询角色信息
     * */
    List<Power_RoleVo> findSomeByMore(Power_RoleVo powerRole, HttpServletRequest request);

    /**
     * @Date 2019-4-16
     * @Author ly
     *  @Description 返回符合条件的角色总记录数
     * */
    int getTotal(Power_RoleVo powerRole,HttpServletRequest request);

    /**
     * @Date 2019-4-25
     * @Author ly
     *  @Description 导出Excel表
     * */
    void export(Power_RoleVo powerRole,HttpServletResponse response,HttpServletRequest request)throws Exception;

    /**
     * @Date 2019-4-25
     * @Author ly
     *  @Description 导出Excel表
     * */
    void exportNotDown(Power_RoleVo powerRole,HttpServletResponse response,HttpServletRequest request)throws Exception;

    /**
     * @Date 2019-4-30
     * @Author ly
     *  @Description 查询角色列表
     * */
    List<Power_RoleVo>selectList();

    /**
     * @Date 2019-07-31
     * @Author zengwenhe
     *  @Description 根据权限查询角色列表
     * */
    List<Power_RoleVo> selectListByPower(HttpServletRequest request);

    /**
     * @Date 2019-08-02
     * @Author zengwenhe
     *  @Description 验证角色名是否重复
     * */
    Power_Role checkRoleName(String roleName);


}
